==> Pouches-1.1.0-sources.jar: fun/wich/EntityPouchItem.java <==
package fun.wich;

import net.minecraft.class_11580;
import net.minecraft.class_124;
import net.minecraft.class_1269;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1308;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1838;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_243;
import net.minecraft.class_2487;
import net.minecraft.class_2561;
import net.minecraft.class_3218;
import net.minecraft.class_3419;
import net.minecraft.class_3468;
import net.minecraft.class_3730;
import net.minecraft.class_5712;
import net.minecraft.class_9279;
import net.minecraft.class_9334;
import net.minecraft.entity.*;

public class EntityPouchItem extends PouchItem {
	public EntityPouchItem(class_1793 settings) { super(settings); }
	@Override
	public class_1269 method_7884(class_1838 context) {
		class_1657 player = context.method_8036();
		class_1799 stack = context.method_8041();
		this.onEmptied(player, context.method_8045(), stack, context.method_8037().method_10093(context.method_8038()));
		player.method_7259(class_3468.field_15372.method_14956(this));
		player.method_6122(context.method_20287(), getEmptiedStack(stack, player));
		return class_1269.field_5812;
	}
	@Override
	public class_2561 method_7864(class_1799 stack) {
		class_11580<class_1299<?>> typedEntityData = stack.method_58694(class_9334.field_49609);
		class_9279 customData = stack.method_58694(class_9334.field_49628);
		if (typedEntityData != null) {
			class_2487 nbt = typedEntityData.method_72540();
			String name = nbt.method_68564("CustomName", null);
			class_2561 mob;
			if (name != null) mob = class_2561.method_43470(name);
			else {
				class_1299<?> entityType = typedEntityData.method_72530();
				if (entityType != null) {
					mob = class_2561.method_43471(entityType.method_5882());
					boolean isBaby = customData != null && customData.method_57461().method_68566("IsBaby", false);
					if (isBaby) mob = class_2561.method_43471("item.wich.pouch_baby").method_10852(mob);
				}
				else mob = class_2561.method_43471("item.wich.pouch_invalid");
			}
			return class_2561.method_43471("item.wich.pouch_of").method_10852(mob).method_27692(class_124.field_1068);
		}
		return super.method_7864(stack);
	}
	public class_1299<?> getEntityType(class_1799 stack) {
		class_11580<class_1299<?>> typedEntityData = stack.method_58694(class_9334.field_49609);
		return typedEntityData != null ? typedEntityData.method_72530() : null;
	}
	public void onEmptied(class_1309 user, class_1937 world, class_1799 stack, class_2338 pos) {
		if (world instanceof class_3218 serverWorld) {
			world.method_8396(null, pos, Pouches.ITEM_POUCH_EMPTY, class_3419.field_15254, 1.0f, 1.0f);
			class_11580<class_1299<?>> typedEntityData = stack.method_58694(class_9334.field_49609);
			if (typedEntityData == null) return;
			class_1299<?> entityType = typedEntityData.method_72530();
			class_2487 nbt = typedEntityData.method_72540();
			nbt.method_67494("Pos", class_243.field_38277, pos.method_61082());
			stack.method_57379(class_9334.field_49609, class_11580.method_72535(entityType, nbt));
			if (entityType == null) return;
			class_1297 entity = entityType.method_5894(serverWorld, stack, user, pos, class_3730.field_16473, true, false);
			if (entity != null) {
				world.method_33596(user, class_5712.field_28738, pos);
				if (entity instanceof class_1308 mob) mob.method_5966();
			}
		}
	}
}

==> Pouches-1.3.0-sources.jar: fun/wich/EntityPouchItem.java <==
package fun.wich;

import net.minecraft.class_11580;
import net.minecraft.class_124;
import net.minecraft.class_1269;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1308;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1838;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_243;
import net.minecraft.class_2487;
import net.minecraft.class_2561;
import net.minecraft.class_3218;
import net.minecraft.class_3419;
import net.minecraft.class_3468;
import net.minecraft.class_3730;
import net.minecraft.class_5712;
import net.minecraft.class_9279;
import net.minecraft.class_9334;
import net.minecraft.entity.*;

public class EntityPouchItem extends PouchItem {
	public EntityPouchItem(class_1793 settings) { super(settings); }
	@Override
	public class_1269 method_7884(class_1838 context) {
		class_1657 player = context.method_8036();
		class_1799 stack = context.method_8041();
		this.onEmptied(player, context.method_8045(), stack, context.method_8037().method_10093(context.method_8038()));
		if (player != null) {
			player.method_7259(class_3468.field_15372.method_14956(this));
			player.method_6122(context.method_20287(), getEmptiedStack(stack, player));
		}
		return class_1269.field_5812;
	}
	@Override
	public class_2561 method_7864(class_1799 stack) {
		class_11580<class_1299<?>> typedEntityData = stack.method_58694(class_9334.field_49609);
		class_9279 customData = stack.method_58694(class_9334.field_49628);
		if (typedEntityData != null) {
			class_2487 nbt = typedEntityData.method_72540();
			String name = nbt.method_68564("CustomName", null);
			class_2561 mob;
			if (name != null) mob = class_2561.method_43470(name);
			else {
				class_1299<?> entityType = typedEntityData.method_72530();
				if (entityType != null) {
					mob = class_2561.method_43471(entityType.method_5882());
					boolean isBaby = customData != null && customData.method_57461().method_68566("IsBaby", false);
					if (isBaby) mob = class_2561.method_43471("item.wich.pouch_baby").method_10852(mob);
				}
				else mob = class_2561.method_43471("item.wich.pouch_invalid");
			}
			return class_2561.method_43471("item.wich.pouch_of").method_10852(mob).method_27692(class_124.field_1068);
		}
		return super.method_7864(stack);
	}
	public void onEmptied(class_1309 user, class_1937 world, class_1799 stack, class_2338 pos) {
		if (world instanceof class_3218 serverWorld) {
			world.method_8396(null, pos, Pouches.ITEM_POUCH_EMPTY, class_3419.field_15254, 1.0f, 1.0f);
			class_11580<class_1299<?>> typedEntityData = stack.method_58694(class_9334.field_49609);
			if (typedEntityData == null) return;
			class_1299<?> entityType = typedEntityData.method_72530();
			class_2487 nbt = typedEntityData.method_72540();
			nbt.method_67494("Pos", class_243.field_38277, pos.method_61082());
			stack.method_57379(class_9334.field_49609, class_11580.method_72535(entityType, nbt));
			if (entityType == null) return;
			class_1297 entity = entityType.method_5894(serverWorld, stack, user, pos, class_3730.field_16473, true, false);
			if (entity != null) {
				world.method_33596(user, class_5712.field_28738, pos);
				if (entity instanceof class_1308 mob) mob.method_5966();
			}
		}
	}
}
